/*
 * This file is part of Skyward Hub.
 *
 * Skyward Hub is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Skyward Hub is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Skyward Hub. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#pragma once

#include <Core/Message/Filter.h>

#include <QObject>
#include <functional>

class Module;

class MessageBroker : public QObject
{
    Q_OBJECT

public:
    using Callback = std::function<void(const Message&, const Filter&)>;

    static MessageBroker& getInstance();

    void subscribe(Filter filter, Module* observer, Callback callback);

    /**
     * @brief Unsubscribe the module from the filter.
     */
    void unsubscribe(Filter filter, Module* module);

    /**
     * @brief Publish a message to all its subscribers.
     */
    void publish(const Message& message);

private:
    MessageBroker() {}

    QMultiMap<Filter, QPair<Module*, Callback*>> observers;

private slots:
    void onModuleDeleted(Module* module);

    // public:
    //     MessageBroker(const MessageBroker&)            = delete;
    //     MessageBroker& operator=(const MessageBroker&) = delete;
};
