/*
 * This file is part of Skyward Hub.
 *
 * Skyward Hub is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Skyward Hub is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Skyward Hub. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#pragma once

#include <Core/XmlObject.h>
#include <Modules/CommandPad/MessageFormElement.h>
#include <Modules/Module.h>

#include <QBoxLayout>
#include <QCheckBox>
#include <QComboBox>
#include <QDialog>
#include <QGridLayout>
#include <QLineEdit>
#include <QMap>
#include <QPushButton>
#include <QString>

class CommandSelector : public QDialog
{
    Q_OBJECT

public:
    explicit CommandSelector(Module* parent);
    ~CommandSelector();

    XmlObject toXmlObject(XmlObject& obj);
    void fromXmlObject(const XmlObject& xmlObject);

    bool getSelection(QString& label, Message& message,
                      long& continuosSendTimeout);

private:
    void setupUi();

    QString currentMessage;
    QVBoxLayout* outerLayout;
    QLineEdit *lineEdit, *continuosTimeoutEdit;
    QComboBox* messagesListComboBox;
    QMap<QString, MessageFormElement*> formElements;
    QGridLayout* formGridLayout;
    QPushButton* sendButton;
    QCheckBox* continuosCheck;

    bool selected = false;
    QString selectedLabel;
    Message selectedMessage;

    Module* parent;
};
