/*
 * This file is part of Skyward Hub.
 *
 * Skyward Hub is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Skyward Hub is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Skyward Hub. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#pragma once

#include <QList>
#include <QMap>
#include <QString>

namespace MainStatesList
{

// Rockets states
enum class State : int
{
    ON_GROUND = 0,
    INIT,
    INIT_ERROR,
    INIT_DONE,
    CALIBRATE_SENSORS,
    CALIBRATE_ALGORITHMS,
    DISARMED,
    TEST_MODE,
    ARMED,
    IGNITION,
    FLYING,
    POWERED_ASCENT,
    UNPOWERED_ASCENT,
    DROGUE_DESCENT,
    TERMINAL_DESCENT,
    LANDED,
    INVALID,
};

// Groundstation labels
static const QList<QString> statesLabels{
    "INIT",
    "CALIBRATE\nSENSORS",
    "CALIBRATE\nALGORITHMS",
    "DISARMED",
    "TEST\nMODE",
    "ARMED",
    "POWERED\nASCENT",
    "UNPOWERED\nASCENT",
    "DROGUE\nDESCENT",
    "TERMINAL\nDESCENT",
    "LANDED",
};

// Map from rocket states to groundstation labels
static const QMap<State, int> statesIndexes{{State::INVALID, -1},
                                            {State::ON_GROUND, -1},
                                            {State::IGNITION, -1},
                                            {State::FLYING, -1},
                                            {State::INIT, 0},
                                            {State::INIT_ERROR, 0},
                                            {State::INIT_DONE, 0},
                                            {State::CALIBRATE_SENSORS, 1},
                                            {State::CALIBRATE_ALGORITHMS, 2},
                                            {State::DISARMED, 3},
                                            {State::TEST_MODE, 4},
                                            {State::ARMED, 5},
                                            {State::POWERED_ASCENT, 6},
                                            {State::UNPOWERED_ASCENT, 7},
                                            {State::DROGUE_DESCENT, 8},
                                            {State::TERMINAL_DESCENT, 9},
                                            {State::LANDED, 10}};

}  // namespace MainStatesList