/*
 * This file is part of Skyward Hub.
 *
 * Skyward Hub is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Skyward Hub is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Skyward Hub. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#pragma once

#include <QMap>

#include "ModuleInfo.h"

class ModulesList
{
public:
    static ModulesList &getInstance();
    ModulesList(const ModulesList &)            = delete;
    ModulesList &operator=(const ModulesList &) = delete;

    QString getModuleName(ModuleId id);
    QString getXmlName(ModuleId id);

    std::function<Module *()> getFactoryMethod(ModuleId id);
    std::function<Module *()> getFactoryMethod(const QString &name);

    QList<QString> getModulesNamesList();
    bool getModuleId(QString name, ModuleId &id);
    QList<ModuleInfo> getModulesInfo();

    Module *instantiateModule(ModuleId id);
    Module *instantiateModule(const QString &name);

private:
    ModulesList();
    QList<ModuleInfo> modulesInfo;
};
